summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorErik Johnson <palehose@gmail.com>2017-05-02 11:23:36 -0500
committerErik Johnson <palehose@gmail.com>2017-05-02 14:57:32 -0500
commit3a4fa79e1c707b0f9354677410cc84b1f5db1cb8 (patch)
tree90adb84dd3949d05e8103d044b122d9f6c8705f9
parent72b9b723594354cafd0f83c24aa0401659d89de8 (diff)
downloaddocker-py-3a4fa79e1c707b0f9354677410cc84b1f5db1cb8.tar.gz
Documentation fixes for login func
This makes a small tweak to the grammar of the documentation for the reauth argument, and also updates the dockercfg_path docs for accuracy. Signed-off-by: Erik Johnson <palehose@gmail.com>
-rw-r--r--docker/api/daemon.py9
1 files changed, 5 insertions, 4 deletions
diff --git a/docker/api/daemon.py b/docker/api/daemon.py
index 91c777f..285b742 100644
--- a/docker/api/daemon.py
+++ b/docker/api/daemon.py
@@ -100,10 +100,11 @@ class DaemonApiMixin(object):
email (str): The email for the registry account
registry (str): URL to the registry. E.g.
``https://index.docker.io/v1/``
- reauth (bool): Whether refresh existing authentication on the
- Docker server.
- dockercfg_path (str): Use a custom path for the ``.dockercfg`` file
- (default ``$HOME/.dockercfg``)
+ reauth (bool): Whether or not to refresh existing authentication on
+ the Docker server.
+ dockercfg_path (str): Use a custom path for the Docker config file
+ (default ``$HOME/.docker/config.json`` if present,
+ otherwise``$HOME/.dockercfg``)
Returns:
(dict): The response from the login request